@@ -24,6 +24,8 @@ var texts = {
     showhideaxes: "Mostrar/ocultar ejes",
     showhideimages: "Mostrar/ocultar imágenes",
     showhidesidebar: "Mostrar/ocultar control lateral",
+    showhidebuttons: "Mostrar/ocultar botones",
+    showhidetables: "Mostrar/ocultar tablas",
     stopresume: "Parar/reanudar",
     netheatmap: "Red/mapa de color",
     isolateselection: "Filtrar selección",
@@ -44,12 +46,14 @@ var texts = {
     ofsomeone: "de",
     withsomeone: "con",
     incidences: "Incidencias",
-    ltexpected: "< Esperadas",
-    gtexpected: "> Esperadas",
-    confidence: "Intervalo de confianza",
-    subjectselect: "Selección de eventos",
+    expected: "Esperadas",
+    expectedconfidence: "+/- Confianza esperada",
+    confidenceinterval: "+/- Intervalo de confianza",
+    subjectselect: "Evento",
     Label: "Etiqueta",
+    LabelSize: "Tam.Eti.",
     Group: "Grupo",
+    Order: "Orden",
     OrderA: "A Orden",
     OrderD: "D Orden",
     Size: "Tamaño",
@@ -70,5 +74,10 @@ var texts = {
     "triangle-up": "Triangulo-arriba",
     trianglesquare: "Triángulo/cuadrado",
     selectacolorscale: "Selecciona una escala de color para ",
-    outof: "de"
+    outof: "de",
+    scenarios: "Número de escenarios",
+    resetzoom: "Reiniciar zoom",
+    removefilter: "Quitar filtro",
+    alertrecordheatmap: "El mapa de color no puede ser grabado.",
+    speed: "Velocidad"
   };
